==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/contextbrowser/kdevcontextbrowser.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=code-context
Exec=blubb
Comment=This plugin shows information about the current language context in a side view, and highlights relevant declarations and uses.
Comment[bg]=Този приставка показва информация за текущата езикова настройка погледната отвън и маркира съответните декларации и употреби.
Comment[bs]=Ovaj dodatak pokazuje informacije o trenutnom jezičkom kontekstu sa strane,  i ističe relevantne deklaracije i upotrebe.
Comment[ca]=Aquest connector mostra informació quant al context del llenguatge actual en una vista lateral i ressalta les declaracions i els usos apropiats.
Comment[ca@valencia]=Este connector mostra informació quant al context del llenguatge actual en una vista lateral i ressalta les declaracions i els usos apropiats.
Comment[da]=Dette plugin viser information om den sprogkontekst i et sidepanel og fremhæver relevante erklæringer og brug.
Comment[de]=Dieses Modul zeigt Informationen über den aktuellen Sprachkontext an und hebt die wichtigen Deklarationen und Vorkommen hervor.
Comment[el]=Αυτό το πρόσθετο εμφανίζει πληροφορίες σχετικά με την τρέχουσα γλώσσα σε μια πλευρική προβολή, και τονίζει τις σχετικές δηλώσεις και χρήσεις.
Comment[en_GB]=This plugin shows information about the current language context in a side view, and highlights relevant declarations and uses.
Comment[es]=Este complemento muestra información sobre el contexto del lenguaje actual en una vista lateral, resaltando declaraciones y usos pertinentes.
Comment[et]=See plugin pakub külgvaates teavet aktiivse keele konteksti kohta ning tõstab esile asjakohased deklaratsioonid ja kasutused.
Comment[fi]=Tämä liitännäinen näyttää tietoja nykyisestä kielikontekstista sivunäkymässä ja korostaa olennaisia esittelyjä ja käyttöjä.
Comment[fr]=Ce module externe affiche des informations sur le contexte du langage actuel dans une vue latérale, et met en surbrillance les déclarations et utilisations pertinentes.
Comment[gl]=Este complemento mostra información acerca do contexto da linguaxe actual nunha vista lateral, e realza as declaracións e utilizacións relevantes.
Comment[hu]=Ez a bővítmény a jelenlegi nyelvi környezetről jelenít meg információkat egy oldalnézetben és kiemeli a lényeges deklarációkat és használatokat.
Comment[it]=Questa estensione mostra le informazioni sul contesto del linguaggio corrente in una vista laterale, mettendo in evidenza le dichiarazioni e gli usi.
Comment[kk]=Бұл плагині, бүйірдегі көріністе, қолданыстағы тілінің контексті туралы мәліметті келтіреді және тиісті мәлімдемелер мен қолдануларын бояп белгілейді.
Comment[nb]=Dette programtillegget viser informasjon om gjeldende språkkontekst i et sidevindu, og fremhever relevante deklarasjoner og bruk.
Comment[nds]=Dit Moduul wiest binnen en Sietpaneel Informatschonen över den aktuellen Spraakkontext un heevt wichtig Deklaratschonen un Bruken rut.
Comment[nl]=Deze plugin toont informatie over de huidige taalcontext in een zijvak en accentueert relevante declaraties en gebruik.
Comment[pl]=Ta wtyczka pokazuje informacje dotyczące kontekstu bieżącego języka w widoku bocznym, podświetla deklaracja i ich użycia.
Comment[pt]=Este 'plugin' mostra informações sobre o contexto actual da linguagem numa visão lateral, realçando as declarações e utilizações relevantes.
Comment[pt_BR]=Este plugin mostra informações sobre a linguagem utilizada no momento, numa visão lateral, e destaca declarações relevantes e seus usos.
Comment[ru]=Это расширение показывает информацию о контексте текущего языка в боковой панели и высвечивает связанные объявления и вхождения.
Comment[sk]=Tento plugin zobrazuje informácie o aktuálnom jazykovom kontexte v božnom pohľade, a zvýrazní relevantné deklarácie a použitia.
Comment[sl]=Vstavek prikazuje podatke o trenutnem kontekstu jezika in poudari pomembne deklaracije in uporabe.
Comment[sv]=Insticksprogrammet visar information om nuvarande språksammanhang i en sidovy, och markerar relevanta deklarationer och användningar.
Comment[tr]=Bu eklenti, yan görünüm içerisinde geçerli dil bağlamında bilgiler gösterir ve uygun bildirimleri ve kullanımları vurgular.
Comment[uk]=За допомогою цього додатка можна переглянути у перегляді на бічній панелі відомості про поточний контекст мови, а також підсвітити пов’язані оголошення і випадки використання.
Comment[x-test]=xxThis plugin shows information about the current language context in a side view, and highlights relevant declarations and uses.xx
Comment[zh_CN]=此插件在侧边视图中显示关于当前语言上下文的信息，并加亮突出相关的声明和调用。
Comment[zh_TW]=此外掛程式顯示關於目前語言的資訊，並將相關的宣告與使用突顯出來。
Name=Code Browser
Name[bg]=Браузър за низове
Name[bs]=Pregledač koda
Name[ca]=Navegador de codi
Name[ca@valencia]=Navegador de codi
Name[cs]=Prohlížeč kódu
Name[da]=Kodebrowser
Name[de]=Quelltext-Browser
Name[el]=Περιηγητής κώδικα
Name[en_GB]=Code Browser
Name[es]=Navegador de código
Name[et]=Koodibrauser
Name[fi]=Lähdekoodiselain
Name[fr]=Navigateur de code
Name[gl]=Navegador do código
Name[hu]=Kódböngésző
Name[it]=Browser del codice
Name[ja]=コードブラウザ
Name[kk]=Код шолғышы
Name[nb]=Kodeleser
Name[nds]=Kodekieker
Name[nl]=Broncode-browser
Name[pa]=ਕੋਡ ਬਰਾਊਜ਼ਰ
Name[pl]=Przeglądarka kodu
Name[pt]=Navegador do Código
Name[pt_BR]=Navegador de código
Name[ru]=Навигация по коду
Name[sk]=Prehliadač kódu
Name[sl]=Brskalnik po kodi
Name[sv]=Kodbläddrare
Name[tr]=Kod Tarayıcı
Name[ug]=كود كۆرگۈ
Name[uk]=Переглядач коду
Name[x-test]=xxCode Browserxx
Name[zh_CN]=代码浏览器
Name[zh_TW]=源碼瀏覽器
GenericName=Code Navigation Tool
GenericName[bg]=Инструмент за управление на низове
GenericName[bs]=Navigacijski alat za kod
GenericName[ca]=Eina de navegació de codi
GenericName[ca@valencia]=Eina de navegació de codi
GenericName[da]=Værktøj til kodenavigation
GenericName[de]=Werkzeug zur Quelltextnavigation
GenericName[el]=Εργαλείο πλοήγησης κώδικα
GenericName[en_GB]=Code Navigation Tool
GenericName[es]=Herramienta de navegación por el código
GenericName[et]=Koodi liikumistööriist
GenericName[fi]=Lähdekoodinavigointityökalu
GenericName[fr]=Outil de navigation de code
GenericName[gl]=Utilidade de navegación polo código
GenericName[hu]=Kódnavigációs eszköz
GenericName[it]=Strumento di navigazione del codice
GenericName[ja]=コードナビゲーションツール
GenericName[kk]=Кодты ақтару құралы
GenericName[nb]=Kodenavigeringsverktøy
GenericName[nds]=Kode-Navigatschoon
GenericName[nl]=Hulpmiddel voor navigatie door code
GenericName[pl]=Narzędzie do nawigacji w kodzie
GenericName[pt]=Ferramenta de Navegação do Código
GenericName[pt_BR]=Ferramenta de navegação de código
GenericName[ru]=Средство навигации по коду
GenericName[sk]=Nástroj navigácie v kóde
GenericName[sl]=Orodje za krmarjenje po kodi
GenericName[sv]=Kodnavigeringsverktyg
GenericName[tr]=Kod Tarama Eklentisi
GenericName[ug]=كود يولباشچى قورالى
GenericName[uk]=Інструмент навігації кодом
GenericName[x-test]=xxCode Navigation Toolxx
GenericName[zh_CN]=代码导航工具
GenericName[zh_TW]=源碼導覽工具
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcontextbrowser
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevcontextbrowser
X-KDE-PluginInfo-Author=David Nolden
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-IRequired=org.kdevelop.IQuickOpen
X-KDevelop-Interfaces=org.kdevelop.IContextBrowser
X-KDevelop-Mode=GUI

==> kdevplatform-1.7.1.tar.xz: kdevplatform-1.7.1/plugins/contextbrowser/kdevcontextbrowser.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=code-context
Exec=blubb
Comment=This plugin shows information about the current language context in a side view, and highlights relevant declarations and uses.
Comment[bg]=Този приставка показва информация за текущата езикова настройка погледната отвън и маркира съответните декларации и употреби.
Comment[bs]=Ovaj dodatak pokazuje informacije o trenutnom jezičkom kontekstu sa strane,  i ističe relevantne deklaracije i upotrebe.
Comment[ca]=Aquest connector mostra informació quant al context del llenguatge actual en una vista lateral i ressalta les declaracions i els usos apropiats.
Comment[ca@valencia]=Este connector mostra informació quant al context del llenguatge actual en una vista lateral i ressalta les declaracions i els usos apropiats.
Comment[da]=Dette plugin viser information om den sprogkontekst i et sidepanel og fremhæver relevante erklæringer og brug.
Comment[de]=Dieses Modul zeigt Informationen über den aktuellen Sprachkontext an und hebt die wichtigen Deklarationen und Vorkommen hervor.
Comment[el]=Αυτό το πρόσθετο εμφανίζει πληροφορίες σχετικά με την τρέχουσα γλώσσα σε μια πλευρική προβολή, και τονίζει τις σχετικές δηλώσεις και χρήσεις.
Comment[en_GB]=This plugin shows information about the current language context in a side view, and highlights relevant declarations and uses.
Comment[es]=Este complemento muestra información sobre el contexto del lenguaje actual en una vista lateral, resaltando declaraciones pertinentes y usos.
Comment[et]=See plugin pakub külgvaates teavet aktiivse keele konteksti kohta ning tõstab esile asjakohased deklaratsioonid ja kasutused.
Comment[fi]=Tämä liitännäinen näyttää tietoja nykyisestä kielikontekstista sivunäkymässä ja korostaa olennaisia esittelyjä ja käyttöjä.
Comment[fr]=Ce module externe affiche des informations sur le contexte du langage actuel dans une vue latérale, et met en surbrillance les déclarations et utilisations pertinentes.
Comment[gl]=Este complemento mostra información acerca do contexto da linguaxe actual nunha vista lateral, e realza as declaracións e utilizacións relevantes.
Comment[hu]=Ez a bővítmény a jelenlegi nyelvi környezetről jelenít meg információkat egy oldalnézetben és kiemeli a lényeges deklarációkat és használatokat.
Comment[it]=Questa estensione mostra le informazioni sul contesto del linguaggio corrente in una vista laterale, mettendo in evidenza le dichiarazioni e gli usi.
Comment[kk]=Бұл плагині, бүйірдегі көріністе, қолданыстағы тілінің контексті туралы мәліметті келтіреді және тиісті мәлімдемелер мен қолдануларын бояп белгілейді.
Comment[nb]=Dette programtillegget viser informasjon om gjeldende språkkontekst i et sidevindu, og fremhever relevante deklarasjoner og bruk.
Comment[nds]=Dit Moduul wiest binnen en Sietpaneel Informatschonen över den aktuellen Spraakkontext un heevt wichtig Deklaratschonen un Bruken rut.
Comment[nl]=Deze plugin toont informatie over de huidige taalcontext in een zijvak en accentueert relevante declaraties en gebruik.
Comment[pl]=Ta wtyczka pokazuje informacje dotyczące kontekstu bieżącego języka w widoku bocznym, podświetla deklaracja i ich użycia.
Comment[pt]=Este 'plugin' mostra informações sobre o contexto actual da linguagem numa visão lateral, realçando as declarações e utilizações relevantes.
Comment[pt_BR]=Este plugin mostra informações sobre a linguagem utilizada no momento, numa visão lateral, e destaca declarações relevantes e seus usos.
Comment[ru]=Это расширение показывает информацию о контексте текущего языка в боковой панели и высвечивает связанные объявления и вхождения.
Comment[sk]=Tento plugin zobrazuje informácie o aktuálnom jazykovom kontexte v božnom pohľade, a zvýrazní relevantné deklarácie a použitia.
Comment[sl]=Vstavek prikazuje podatke o trenutnem kontekstu jezika in poudari pomembne deklaracije in uporabe.
Comment[sv]=Insticksprogrammet visar information om nuvarande språksammanhang i en sidovy, och markerar relevanta deklarationer och användningar.
Comment[tr]=Bu eklenti, yan görünüm içerisinde geçerli dil bağlamında bilgiler gösterir ve uygun bildirimleri ve kullanımları vurgular.
Comment[uk]=За допомогою цього додатка можна переглянути у перегляді на бічній панелі відомості про поточний контекст мови, а також підсвітити пов’язані оголошення і випадки використання.
Comment[x-test]=xxThis plugin shows information about the current language context in a side view, and highlights relevant declarations and uses.xx
Comment[zh_CN]=此插件在侧边视图中显示关于当前语言上下文的信息，并加亮突出相关的声明和调用。
Comment[zh_TW]=此外掛程式顯示關於目前語言的資訊，並將相關的宣告與使用突顯出來。
Name=Code Browser
Name[bg]=Браузър за низове
Name[bs]=Pregledač koda
Name[ca]=Navegador de codi
Name[ca@valencia]=Navegador de codi
Name[cs]=Prohlížeč kódu
Name[da]=Kodebrowser
Name[de]=Quelltext-Browser
Name[el]=Περιηγητής κώδικα
Name[en_GB]=Code Browser
Name[es]=Navegador de código
Name[et]=Koodibrauser
Name[fi]=Lähdekoodiselain
Name[fr]=Navigateur de code
Name[gl]=Navegador do código
Name[hu]=Kódböngésző
Name[it]=Browser del codice
Name[ja]=コードブラウザ
Name[kk]=Код шолғышы
Name[nb]=Kodeleser
Name[nds]=Kodekieker
Name[nl]=Broncode-browser
Name[pa]=ਕੋਡ ਬਰਾਊਜ਼ਰ
Name[pl]=Przeglądarka kodu
Name[pt]=Navegador do Código
Name[pt_BR]=Navegador de código
Name[ru]=Навигация по коду
Name[sk]=Prehliadač kódu
Name[sl]=Brskalnik po kodi
Name[sv]=Kodbläddrare
Name[tr]=Kod Tarayıcı
Name[ug]=كود كۆرگۈ
Name[uk]=Переглядач коду
Name[x-test]=xxCode Browserxx
Name[zh_CN]=代码浏览器
Name[zh_TW]=源碼瀏覽器
GenericName=Code Navigation Tool
GenericName[bg]=Инструмент за управление на низове
GenericName[bs]=Navigacijski alat za kod
GenericName[ca]=Eina de navegació de codi
GenericName[ca@valencia]=Eina de navegació de codi
GenericName[da]=Værktøj til kodenavigation
GenericName[de]=Werkzeug zur Quelltextnavigation
GenericName[el]=Εργαλείο πλοήγησης κώδικα
GenericName[en_GB]=Code Navigation Tool
GenericName[es]=Herramienta de navegación por el código
GenericName[et]=Koodi liikumistööriist
GenericName[fi]=Lähdekoodinavigointityökalu
GenericName[fr]=Outil de navigation de code
GenericName[gl]=Utilidade de navegación polo código
GenericName[hu]=Kódnavigációs eszköz
GenericName[it]=Strumento di navigazione del codice
GenericName[ja]=コードナビゲーションツール
GenericName[kk]=Кодты ақтару құралы
GenericName[nb]=Kodenavigeringsverktøy
GenericName[nds]=Kode-Navigatschoon
GenericName[nl]=Hulpmiddel voor navigatie door code
GenericName[pl]=Narzędzie do nawigacji w kodzie
GenericName[pt]=Ferramenta de Navegação do Código
GenericName[pt_BR]=Ferramenta de navegação de código
GenericName[ru]=Средство навигации по коду
GenericName[sk]=Nástroj navigácie v kóde
GenericName[sl]=Orodje za krmarjenje po kodi
GenericName[sv]=Kodnavigeringsverktyg
GenericName[tr]=Kod Tarama Eklentisi
GenericName[ug]=كود يولباشچى قورالى
GenericName[uk]=Інструмент навігації кодом
GenericName[x-test]=xxCode Navigation Toolxx
GenericName[zh_CN]=代码导航工具
GenericName[zh_TW]=源碼導覽工具
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcontextbrowser
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevcontextbrowser
X-KDE-PluginInfo-Author=David Nolden
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-IRequired=org.kdevelop.IQuickOpen
X-KDevelop-Interfaces=org.kdevelop.IContextBrowser
X-KDevelop-Mode=GUI
